# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgname openvswitch2.17


%if 0%{?commit:1}
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%endif

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# FIXME Test "STP - flush the fdb and mdb when topology changed" fails on s390x
# FIXME 2 tests fails on ppc64le. They will be hopefully fixed before official 2.11
%ifarch %{ix86} x86_64 aarch64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel
# option to build with libcap-ng, needed for running OVS as regular user
%bcond_without libcapng
# option to build with ipsec support
%bcond_without ipsec

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

Name: %{pkgname}
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 2.17.0
Release: 50%{?dist}

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define dpdkver 21.11
%define dpdkdir dpdk
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
# NOTE: DPDK does not currently build for s390x
# DPDK on aarch64 is not stable enough to be enabled in FDP
%if 0%{?rhel} > 7 || 0%{?fedora}
%define dpdkarches x86_64 ppc64le
%else
%define dpdkarches
%endif

%if 0%{?commit:1}
Source: https://github.com/openvswitch/ovs/archive/%{commit}.tar.gz#/openvswitch-%{commit}.tar.gz
%else
Source: https://github.com/openvswitch/ovs/archive/v%{version}.tar.gz#/openvswitch-%{version}.tar.gz
%endif
Source10: https://fast.dpdk.org/rel/dpdk-%{dpdkver}.tar.xz

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.2.3
%define pyelftoolsver 0.27
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz
Source103: https://pypi.io/packages/source/p/pyelftools/pyelftools-%{pyelftoolsver}.tar.gz

Patch:     openvswitch-%{version}.patch

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted assembly instructions.  As such it
# needs extensive work to port it to other architectures.
ExclusiveArch: x86_64 aarch64 ppc64le s390x

# Do not enable this otherwise YUM will break on any upgrade.
# Provides: openvswitch
Conflicts: openvswitch < 2.17
Conflicts: openvswitch-dpdk < 2.17
Conflicts: openvswitch2.10
Conflicts: openvswitch2.11
Conflicts: openvswitch2.12
Conflicts: openvswitch2.13
Conflicts: openvswitch2.14
Conflicts: openvswitch2.15
Conflicts: openvswitch2.16

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel
BuildRequires: systemtap-sdt-devel
# make check dependencies
BuildRequires: procps-ng
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%ifarch %{dpdkarches}
BuildRequires: meson
%if 0%{?rhel} > 8 || 0%{?fedora}
BuildRequires: python3-pyelftools
%endif
# DPDK driver dependencies
BuildRequires: zlib-devel numactl-devel
%ifarch x86_64
BuildRequires: rdma-core-devel >= 15 libmnl-devel
%endif

# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}
%endif

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0
Requires: openvswitch-selinux-extra-policy

Requires(pre): shadow-utils
Requires(post): /bin/sed
Requires(post): /usr/sbin/usermod
Requires(post): /usr/sbin/groupadd
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python3-%{pkgname}
Summary: Open vSwitch python3 bindings
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: python-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description -n python3-%{pkgname}
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: tcpdump

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
This provides shared library, libopenswitch.so and the openvswitch header
files needed to build an external application.

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%package -n network-scripts-%{name}
Summary: Open vSwitch legacy network service support
License: ASL 2.0
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
This provides the ifup and ifdown scripts for use with the legacy network
service.
%endif

%if %{with ipsec}
%package ipsec
Summary: Open vSwitch IPsec tunneling support
License: ASL 2.0
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: libreswan

%description ipsec
This package provides IPsec tunneling support for OVS tunnels.
%endif

%prep
%if 0%{?commit:1}
%setup -q -n ovs-%{commit} -a 10
%else
%setup -q -n ovs-%{version} -a 10
%endif
%if ! %{external_sphinx}
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 100 -a 101 -a 102
%else
%setup -n ovs-%{version} -q -D -T -a 100 -a 101 -a 102
%endif
%endif
%if 0%{?rhel} && 0%{?rhel} < 9
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 103
%else
%setup -n ovs-%{version} -q -D -T -a 103
%endif
%endif

mv dpdk-*/ %{dpdkdir}/

# FIXME should we propose a way to do that upstream?
sed -ri "/^subdir\('(usertools|app)'\)/d" %{dpdkdir}/meson.build

%patch -p1

%build
%if 0%{?rhel} && 0%{?rhel} < 9
export PYTHONPATH="${PWD}/pyelftools-%{pyelftoolsver}"
%endif
# Build Sphinx on RHEL
%if ! %{external_sphinx}
export PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}%{_builddir}/pytmp/lib/python"
for x in docutils-%{docutilsver} Pygments-%{pygmentsver} Sphinx-%{sphinxver}; do
    pushd "$x"
    python2 setup.py install --home %{_builddir}/pytmp
    popd
done

export PATH="$PATH:%{_builddir}/pytmp/bin"
%endif

./boot.sh

%ifarch %{dpdkarches}    # build dpdk
# Lets build DPDK first
cd %{dpdkdir}

ENABLED_DRIVERS=(
    bus/pci
    bus/vdev
    mempool/ring
    net/failsafe
    net/i40e
    net/ring
    net/vhost
    net/virtio
    net/tap
)

%ifarch x86_64
ENABLED_DRIVERS+=(
    bus/auxiliary
    bus/vmbus
    common/iavf
    common/mlx5
    net/bnxt
    net/enic
    net/iavf
    net/ice
    net/mlx5
    net/netvsc
    net/nfp
    net/qede
    net/vdev_netvsc
)
%endif

%ifarch aarch64 x86_64
ENABLED_DRIVERS+=(
    net/e1000
    net/ixgbe
)
%endif

for driver in "${ENABLED_DRIVERS[@]}"; do
    enable_drivers="${enable_drivers:+$enable_drivers,}"$driver
done

# As of 21.11-rc3, following libraries can be disabled:
# optional_libs = [
#         'bitratestats',
#         'gpudev',
#         'gro',
#         'gso',
#         'kni',
#         'jobstats',
#         'latencystats',
#         'metrics',
#         'pdump',
#         'power',
#         'vhost',
# ]
# If doing any updates, this must be aligned with:
# https://access.redhat.com/articles/3538141
DISABLED_LIBS=(
    gpudev
    kni
    jobstats
    power
)

for lib in "${DISABLED_LIBS[@]}"; do
    disable_libs="${disable_libs:+$disable_libs,}"$lib
done

%set_build_flags
%__meson --prefix=%{_builddir}/dpdk-build \
         --buildtype=plain \
         -Ddisable_libs="$disable_libs" \
         -Denable_drivers="$enable_drivers" \
         -Dplatform=generic \
         -Dmax_ethports=1024 \
         -Dmax_numa_nodes=8 \
         -Dtests=false \
         %{_vpath_builddir}
%meson_build
%__meson install -C %{_vpath_builddir} --no-rebuild

# FIXME currently with LTO enabled OVS tries to link with both static and shared libraries
rm -v %{_builddir}/dpdk-build/%{_lib}/*.so*

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in %{_builddir}/dpdk-build/%{_lib}/librte_net_*.a; do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -
%endif    # build dpdk

# And now for OVS...
mkdir build-shared build-static
pushd build-shared
ln -s ../configure
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --disable-static \
        --enable-shared \
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd
pushd build-static
ln -s ../configure
%ifarch %{dpdkarches}
PKG_CONFIG_PATH=%{_builddir}/dpdk-build/%{_lib}/pkgconfig \
%endif
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
%ifarch %{dpdkarches}
        --with-dpdk=static \
%endif
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd

/usr/bin/python3 build-aux/dpdkstrip.py \
        --dpdk \
        < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
        > rhel/usr_lib_systemd_system_ovs-vswitchd.service

%install
rm -rf $RPM_BUILD_ROOT
make -C build-shared install-libLTLIBRARIES DESTDIR=$RPM_BUILD_ROOT
make -C build-static install DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_rundir}/openvswitch
install -d -m 0750 $RPM_BUILD_ROOT%{_localstatedir}/log/openvswitch
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
        $RPM_BUILD_ROOT%{_udevrulesdir}/91-vfio.rules

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch

for service in openvswitch ovsdb-server ovs-vswitchd \
               ovs-delete-transient-ports; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

%if %{with ipsec}
install -p -D -m 0644 rhel/usr_lib_systemd_system_openvswitch-ipsec.service \
                      $RPM_BUILD_ROOT%{_unitdir}/openvswitch-ipsec.service
%endif

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
        $RPM_BUILD_ROOT/%{_sysconfdir}/openvswitch/default.conf

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

%if 0%{?rhel} < 9
install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{python3_sitelib}
cp -a $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/ovstest \
        $RPM_BUILD_ROOT%{python3_sitelib}

# Build the JSON C extension for the Python lib (#1417738)
pushd python
(
export CPPFLAGS="-I ../include -I ../build-shared/include"
export LDFLAGS="%{__global_ldflags} -L $RPM_BUILD_ROOT%{_libdir}"
%py3_build
%py3_install
[ -f "$RPM_BUILD_ROOT/%{python3_sitearch}/ovs/_json$(python3-config --extension-suffix)" ]
)
popd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

install -d -m 0755 $RPM_BUILD_ROOT%{_prefix}/lib/firewalld/services/

install -p -D -m 0755 \
        rhel/usr_share_openvswitch_scripts_ovs-systemd-reload \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovs-systemd-reload

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
# The db needs special permission as IPsec Pre-shared keys are stored in it.
chmod 0640 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8*

%if ! %{with ipsec}
rm -f $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%endif

# remove ovn unpackages files
rm -f $RPM_BUILD_ROOT%{_bindir}/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovn*
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*

%check
%if %{with check}
    pushd build-static
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
    popd
%endif
%if %{with check_datapath_kernel}
    pushd build-static
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
    popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun openvswitch.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable openvswitch.service >/dev/null 2>&1 || :
        /bin/systemctl stop openvswitch.service >/dev/null 2>&1 || :
    fi
%endif

%pre
getent group openvswitch >/dev/null || groupadd -r openvswitch
getent passwd openvswitch >/dev/null || \
    useradd -r -g openvswitch -d / -s /sbin/nologin \
    -c "Open vSwitch Daemons" openvswitch

%ifarch %{dpdkarches}
    getent group hugetlbfs >/dev/null || groupadd hugetlbfs
    usermod -a -G hugetlbfs openvswitch
%endif
exit 0

%post
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVS_USER_ID=:OVS_USER_ID=:' /etc/sysconfig/openvswitch

%ifarch %{dpdkarches}
    sed -i \
        's@OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:hugetlbfs"@'\
        /etc/sysconfig/openvswitch
%endif
fi
chown -R openvswitch:openvswitch /etc/openvswitch

%if 0%{?systemd_post:1}
    %systemd_post openvswitch.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun
%if 0%{?systemd_postun:1}
    %systemd_postun openvswitch.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%triggerun -- openvswitch < 2.5.0-22.git20160727%{?dist}
# old rpm versions restart the service in postun, but
# due to systemd some preparation is needed.
if systemctl is-active openvswitch >/dev/null 2>&1 ; then
    /usr/share/openvswitch/scripts/ovs-ctl stop >/dev/null 2>&1 || :
    systemctl daemon-reload >/dev/null 2>&1 || :
    systemctl stop openvswitch ovsdb-server ovs-vswitchd >/dev/null 2>&1 || :
    systemctl start openvswitch >/dev/null 2>&1 || :
fi
exit 0

%files -n python3-%{pkgname}
%{python3_sitearch}/ovs
%{python3_sitearch}/ovs-*.egg-info
%doc LICENSE

%files test
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{python3_sitelib}/ovstest

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*
%exclude %{_libdir}/*.a
%exclude %{_libdir}/*.la

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%{_sysconfdir}/openvswitch/default.conf
%config %ghost %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/conf.db
%ghost %attr(0600,-,-) %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovs-delete-transient-ports.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-kmod-ctl
%{_datadir}/openvswitch/scripts/ovs-systemd-reload
%config %{_datadir}/openvswitch/local-config.ovsschema
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_libdir}/*.so.*
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovsdb.5*
%{_mandir}/man5/ovsdb.local-config.5*
%{_mandir}/man5/ovsdb-server.5.*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man7/ovsdb-server.7*
%{_mandir}/man7/ovsdb.7*
%{_mandir}/man7/ovs-actions.7*
%{_mandir}/man7/ovs-fields.7*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-kmod-ctl.8.*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%{_udevrulesdir}/91-vfio.rules
%doc LICENSE NOTICE README.rst NEWS rhel/README.RHEL.rst
%ifarch %{dpdkarches}
%doc %{dpdkdir}/README.DPDK-PMDS
%attr(750,openvswitch,hugetlbfs) %verify(not owner group) /var/log/openvswitch
%else
%attr(750,openvswitch,openvswitch) %verify(not owner group) /var/log/openvswitch
%endif
/var/lib/openvswitch
%ghost %attr(755,root,root) %verify(not owner group) %{_rundir}/openvswitch
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_bindir}/ovs-dpctl-top
%{_sbindir}/ovs-bugtool
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-bugtool.8*
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} < 29)
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%if %{with ipsec}
%files ipsec
%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%{_unitdir}/openvswitch-ipsec.service
%endif

%changelog
* Wed Sep 07 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-50
- redhat: use git rev-parse to get BRANCH_NAME [RH git: fbcf506fb4]
    git name-rev may return tag instead of branch name


* Tue Sep 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-49
- Merging 7bcd45ce82 version: 21.11.2 [RH git: 3073fb2b47]
    Commit list:
    7bcd45ce82 version: 21.11.2
    e12d415556 vhost: fix header spanned across more than two descriptors
    f167022606 vhost: discard too small descriptor chains
    25c01bd323 net/mlx5: fix Rx queue recovery mechanism
    125a65cb03 examples/performance-thread: fix build with GCC 12
    2a55c38e27 test/crypto: skip oop test for raw api
    a561d44985 net/vhost: fix null pointer dereference
    0f80c13b4d version: 21.11.2-rc1
    84b2018842 app/testpmd: fix GTP PSC raw processing
    9e7d93ae2f net/iavf: fix GTP-U extension flow
    b11e955370 vdpa/sfc: resolve race between vhost lib and device conf
    06b246ead6 vdpa/ifc/base: fix null pointer dereference
    dbe68f0958 vdpa/mlx5: fix leak on event thread creation
    9224015451 examples/link_status_interrupt: fix stats refresh rate
    b941165a00 examples/vhost: fix retry logic on Rx path
    f169902058 avoid AltiVec keyword vector
    20ee5fbe91 app/regex: fix mbuf size for multi-segment buffer
    81a0919f6a app/regex: avoid division by zero
    e1c3685b21 dma/idxd: fix null dereference in PCI remove
    5b7a2b5672 dma/idxd: fix partial freeing in PCI close
    1fd4a985e4 dma/idxd: fix memory leak in PCI close
    008e1abc82 net/mlx5: reject negative integrity item configuration
    fa1d93b8c4 common/mlx5: fix non-expandable global MR cache
    03a6a9f751 common/cnxk: allow changing PTP mode on CN10K
    8fb51606a7 gro: fix identifying fragmented packets
    e46eb5a8dc service: fix lingering active status
    399cbc736c net/igc: support multi-process
    97e75c37b0 net/iavf: fix VF reset
    bbc9dcaefa common/cnxk: fix GRE tunnel parsing
    36f4c8e67f net/virtio-user: fix Rx interrupts with multi-queue
    c353b1de9f vhost: restore device information in log messages
    1f963ee7a3 vhost: add some trailing newline in log messages
    4ef6a79d4a vdpa/sfc: fix sync between QEMU and vhost-user
    5991d25b74 net/vhost: fix deadlock on vring state change
    a3ff1d7e9c doc: fix readability in vhost guide
    19457a68ea net/virtio-user: fix socket non-blocking mode
    3287afa5e8 net/netvsc: fix vmbus device reference in multi-process
    b6e4963255 app/testpmd: fix supported RSS offload display
    49cc0b73a0 eventdev/eth_tx: fix queue delete
    a1564274cd doc: fix grammar and parameters in l2fwd-crypto guide
    a8b87a7063 doc: fix grammar and formatting in compressdev guide
    8017591016 crypto/qat: fix DOCSIS crash
    f2a62f854e examples/fips_validation: handle empty payload
    390e956b6d test/crypto: fix SNOW3G vector IV format
    35b1acf851 test/crypto: fix ZUC vector IV format
    6706a66aaa test/crypto: fix authentication IV for ZUC SGL
    f95b184d1e doc: add more instructions for running as non-root
    a74fd43471 net/bnxt: fix check for autoneg enablement in the PHY FW
    7a91bb4238 net/bnxt: cleanup MTU setting
    1ab0afa450 net/bnxt: disallow MTU change when device is started
    8185654d05 net/bnxt: fix setting forced speed
    e798345849 net/bnxt: allow Tx only or Rx only
    cce3a4048e net/bnxt: fix switch domain allocation
    17d26c7fa0 examples/distributor: fix distributor on Rx core
    8bbab0b5a5 net/hns3: delete unused code
    32535f69cd net/hns3: fix descriptors check with SVE
    5a05333308 net/hns3: fix statistics locking
    6420d2f828 net/hns3: fix PTP interrupt logging
    bdabb55ddc net/hns3: support backplane media type
    a650bf5cfe net/hns3: fix link status capability query from VF
    44dad33c76 app/testpmd: fix GTP PSC raw processing
    5dee226e46 net: fix GTP PSC headers
    95b87a5314 app/testpmd: fix flex parser destroy command
    2a4ad9bb84 app/testpmd: cleanup port resources after implicit close
    bbf31ae0fc test: check memory allocation for CRC
    ed8a477487 app/procinfo: show all non-owned ports
    6fce2b8067 test/hash: fix out of bound access
    7181c621fb rib: fix references for IPv6 implementation
    1b31f49983 dma/idxd: fix non-AVX builds with old compilers
    d6e109f8aa dma/idxd: fix AVX2 in non-datapath functions
    b72fa6fd7a raw/ioat: fix build when ioat dmadev enabled
    d028271a0a raw/ioat: fix build missing errno include
    a3d0dbcf03 config: fix C++ cross compiler for Arm and PPC
    3a9c3000f4 vdpa/mlx5: fix maximum number of virtqs
    45150fc78b vdpa/mlx5: workaround var offset within page
    0de69e279d doc: fix flow integrity hardware support in mlx5 guide
    02017fcad3 net/mlx5: fix stack buffer overflow in drop action
    f8b370bbb4 net/mlx5: fix metering on E-Switch Manager
    aa8fb4afda net/mlx5: add limitation for E-Switch Manager match
    fac54fde60 net/mlx5: fix RSS expansion for patterns with ICMP item
    de9fa7b453 net/mlx5: fix build with clang 14
    e4939398df net/qede: fix build with GCC 12
    cca0819d48 net/ice/base: fix build with GCC 12
    f361d278e7 net/ice: fix race condition in Rx timestamp
    f294a3dbb0 net/qede: fix build with GCC 13
    760f94b15a common/cnxk: handle ROC model init failure
    3a66cbb695 common/cnxk: fix decrypt packet count register update
    614cd42ac0 net/octeontx: fix port close
    bee8c21938 malloc: fix allocation of almost hugepage size
    7b610e0a8d net/virtio: unmap PCI device in secondary process
    d6e4e0f46e vhost/crypto: fix descriptor processing
    f69a61bde0 vhost/crypto: fix build with GCC 12
    361723acef vhost: fix missing enqueue pseudo-header calculation
    76556a3128 app/testpmd: revert MAC update in checksum forwarding
    1901dc5492 net/ngbe: add more packet statistics
    a92e31d35d net/txgbe: fix register polling
    f48795dea1 app/testpmd: fix bonding slave devices not released
    b3cfb3db85 app/testpmd: add help messages for multi-process
    bfaaf994a5 net/hns3: fix TM capability
    35582af08c net/hns3: fix crash from secondary process
    ba4aa140b3 net/hns3: fix return value for unsupported tuple
    332e5fca03 net/hns3: fix code check warning
    fc61bd5d37 net/hns3: remove duplicate definition
    e885f508d9 net/hns3: fix an unreasonable memset
    8854374c9e test/bonding: fix RSS test when disable RSS
    2b71d44b80 net/bonding: fix RSS inconsistency between ports
    bd9ffc1961 eventdev/eth_tx: fix adapter creation
    19591ad643 event/dlb2: fix advertized capabilities
    f7b34f357c event/cnxk: fix Tx adapter enqueue return for CN10K
    93b1138ccd event/cnxk: fix QoS parameter handling
    e6f569043c event/dlb2: fix check of QID in-flight
    7c0439f319 event/dlb2: rework queue drain handling
    d2c3d326d0 event/octeontx: fix SSO fast path
    bf7aa26ddd net/nfp: fix initialization
    1c770fda6f net/nfp: make sure MTU is never larger than mbuf size
    fe2cddeb08 net/nfp: update how max MTU is read
    095d2af061 crypto/cnxk: swap zuc-256 iv
    38eabfdd0d common/cnxk: swap zuc-256 key
    d1e2bd80a6 test/ipsec: fix performance test
    387d7f2a33 test/crypto: fix cipher offset for ZUC
    bf03e0341c crypto/scheduler: fix queue pair in scheduler failover
    9445fcf138 test/ipsec: fix build with GCC 12
    e0bff8480f crypto/cnxk: fix build with GCC 12
    978835ed87 common/cpt: fix build with GCC 12
    a9485fd00b examples/ipsec-secgw: fix ESN setting
    362a219f40 net/iavf: fix NAT-T payload length
    be3beb946e examples/ipsec-secgw: fix NAT-T header fields
    d6a5fb4092 ipsec: fix NAT-T ports and length
    fd2d725ae5 baseband/acc100: add protection for some negative scenario
    4184a99adb baseband/acc100: update companion PF configure function
    4fb5429816 eal/x86: drop export of internal alignment macro
    bba01c7ab8 sched: remove unnecessary floating point
    03b38f5281 test: drop reference to removed tests
    b55b2820d2 trace: fix init with long file prefix
    17615c81fe trace: fix crash when exiting
    64fdce75b6 net/mlx5: fix RSS hash types adjustment
    1fb92a1f45 net/bnxt: fix tunnel stateless offloads
    e10c862914 net/iavf: fix segfaults when calling API after VF reset failed
    8e8886a0e9 dma/hisilicon: fix includes in header file
    e027f40cd2 dma/skeleton: fix index returned when no memcpy completed
    675b5bdf2c app/flow-perf: fix build with GCC 12
    f85d0fc397 vdpa/ifc: fix build with GCC 12
    ec6a2fa05c net/ice: fix build with GCC 12
    ac8e3a7546 net/enetfec: fix build with GCC 12
    9c1822f59f net/ena: fix build with GCC 12
    c86456efc9 crypto/ipsec_mb: fix build with GCC 12
    4cfe560401 kni: use dedicated function to set MAC address
    9b7982b986 kni: use dedicated function to set random MAC address
    e731132bca net/tap: fix device freeing
    63bb35c3f3 net/failsafe: fix device freeing
    a9062fa2fc app/testpmd: fix multicast address pool leak
    c18ad5cc3e app/testpmd: fix packet segment allocation
    8bb9213bbc dma/idxd: fix error code for PCI device commands
    5215fd05ab doc: fix formatting and link in BPF library guide
    7133eadc9c bus/fslmc: fix VFIO setup
    d2d91f50f7 raw/ifpga: unregister interrupt on close
    56e6acc152 raw/ifpga: remove virtual devices on close
    e06a55362a eal/ppc: fix compilation for musl
    c3a48df3d5 dma/hisilicon: enhance CQ scan robustness
    543121b53e dma/hisilicon: fix index returned when no DMA completed
    d1461844a6 examples/dma: fix Tx drop statistics
    6564af3d39 examples/dma: fix MTU configuration
    5d71b3d9fa common/mlx5: remove unused lcore check
    94b9525189 net/iavf: remove dead code
    f0c897ea5a net/iavf: increase reset complete wait count
    341d13b08b net/iavf: fix device stop
    eab5e035ce net/iavf: fix device initialization without inline crypto
    78cf4cbe62 doc: update matching versions in i40e guide
    d124639aee net/iavf: fix Rx queue interrupt setting
    4a42ee9346 net/iavf: fix mbuf release in multi-process
    e1a84de6a9 net/iavf: fix queue start exception handling
    6730951205 net/i40e: fix max frame size config at port level
    cfa67fc84b net/ice: fix MTU info for DCF
    356142f8a2 net/ice/base: fix direction of flow that matches any
    745563ca3c net/ice/base: fix getting sched node from ID type
    97f8a95696 net/ixgbe: add option for link up check on pin SDP3
    111417a49b net/iavf: fix data path selection
    c8868b3c5c kni: fix build
    3aeeea257f kni: fix build with Linux 5.18
    301300a86e net/mlx5: fix statistics read on Linux
    83abe945a6 net/mlx5: fix Tx recovery
    f06feb0822 examples/vhost: fix crash when no VMDq
    a7c72e3e6c vhost: fix deadlock when message handling failed
    e156da31dd doc: fix vhost multi-queue reconnection
    17a0ef7be3 vhost: fix async access
    c8c6eeda37 net/bnxt: fix ULP parser to ignore segment offset
    ca961550e9 net/bnxt: fix compatibility with some old firmwares
    ee3b68b408 ethdev: fix port close in secondary process
    da7caee013 common/sfc_efx/base: convert EFX PCIe INTF to MCDI value
    959cd86178 net/vmxnet3: fix Rx data ring initialization
    8c381b1157 app/testpmd: fix help of create meter command
    237d93b36c net/nfp: fix disabling VLAN stripping
    b3ef192fec net/txgbe: fix max number of queues for SR-IOV
    7b5339d563 net/txgbe: fix SGMII mode to link up
    8bf4f37ede net/ngbe: fix PCIe related operations with bus API
    512f325928 net/ngbe: fix reading PHY ID
    ba78db53ee net/ngbe: fix link speed check
    8e23b06316 ethdev: fix port state when stop
    54cb103e7b net/memif: fix overwriting of head segment
    fde361696c net/bonding: fix mbuf fast free usage
    ce5917f846 app/testpmd: do not poll stopped queues
    8b28d584d8 app/testpmd: fix use of indirect action after port close
    28e88ef39e ethdev: prohibit polling stopped queue
    011122b9e0 app/testpmd: fix metering and policing command for RFC4115
    e154ece049 app/testpmd: replace hardcoded min mbuf number with macro
    f7638851b4 net/cnxk: fix possible null dereference in telemetry
    c05dd44f52 ethdev: fix possible null pointer access
    e5177f3853 ethdev: fix memory leak in xstats telemetry
    2104014dbd net/axgbe: fix xstats get return if xstats is null
    3422f4b58c net/mvpp2: fix xstats get return if xstats is null
    7a1086a9d5 net/ipn3ke: fix xstats get return if xstats is null
    bae6c70cd3 net/hns3: fix xstats get return if xstats is null
    0c48dafbdf app/testpmd: remove useless pointer checks
    8378498b96 app/testpmd: perform SW IP checksum for GRO/GSO packets
    65bff89f9a app/testpmd: fix port status of bonding slave device
    4f9c7fb5af doc: add missing auth algo for IPsec example
    2d0ec22be8 test/crypto: fix driver name for DPAA raw API test
    082148b6a5 drivers/crypto: fix warnings for OpenSSL version
    48dda925a7 test/crypto: fix null check for ZUC authentication
    c195ec01df examples/ipsec-secgw: fix promiscuous mode option
    9c33903649 examples/ipsec-secgw: fix uninitialized memory access
    ea0ab8e686 pcapng: fix timestamp wrapping in output files
    412da85334 pipeline: fix emit instruction for invalid headers
    ce7b8e673a devtools: fix null test for NUMA systems
    84eb565954 doc: fix API index Markdown syntax
    d55a70f874 mbuf: dump outer VLAN
    2fcd1cc163 rib: fix traversal with /32 route
    8c5ab722fb acl: fix rules with 8-byte field size
    5ffee1e906 test: avoid hang if queues are full and Tx fails
    c1f49d47a9 eal/freebsd: fix use of newer cpuset macros
    214462a05b devargs: fix leak on hotplug failure
    29fa5a6eaf eal/x86: fix unaligned access for small memcpy
    eeaeb58d56 event/cnxk: fix out of bounds access in test
    09d859555f eventdev/eth_rx: fix telemetry Rx stats reset
    ec08dcaf4b doc: fix build with sphinx 4.5
    671e8fa0c8 net/mlx5: fix no-green metering with RSS
    6857653625 net/bnxt: fix freeing VNIC filters
    fa1a893ff7 net/bnxt: recheck FW readiness if in reset process
    2ff3768d20 net/bnxt: fix link status when port is stopped
    71ab79d3a7 net/bnxt: force PHY update on certain configurations
    db239d7290 net/bnxt: fix speed autonegotiation
    ce36a5d910 net/bnxt: avoid unnecessary endianness conversion
    8c464cf618 net/bnxt: handle queue stop during RSS flow create
    c25b1d545e net/bnxt: check duplicate queue IDs
    3f9914a7b3 net/bnxt: fix ring group on Rx restart
    821dd9cd43 net/bnxt: fix RSS action
    3774986bdd net/bnxt: fix Rx configuration
    d620238a97 net/bnxt: remove unused macro
    2f66d10615 net/bnxt: fix device capability reporting
    b174adfcae net/bnxt: fix reordering in NEON Rx
    7d9f5b3b33 net/cnxk: add barrier after meta batch free in scalar
    8790891a6d common/cnxk: fix SQ flush sequence
    08d2d8868e net/cnxk: fix uninitialized variables
    a10e2ec8ee common/cnxk: fix null pointer dereference
    d13786763a common/cnxk: fix unaligned access to device memory
    b117088323 net/cnxk: add message on flow parsing failure
    caf428f0a0 app/testpmd: fix MTU verification
    5e1545b730 app/testpmd: check statistics query before printing
    66b7e330d6 net/hns3: remove unnecessary RSS switch
    15b794b152 ethdev: fix RSS update when RSS is disabled
    0cec1c9477 net/hns3: remove redundant RSS tuple field
    5a6fb3a977 net/hns3: fix rollback on RSS hash update
    8c193c0b4c net/hns3: fix RSS disable
    8b00917c08 net/hns3: fix mbuf free on Tx done cleanup
    74089f471a net/hns3: fix pseudo-sharing between threads
    827f72e8ce net/hns3: fix MAC and queues HW statistics overflow
    d96ee7bac0 net/hns3: fix order of clearing imissed register in PF
    aa2c6d3f69 ethdev: fix build with vtune option
    b839853e83 net/tap: fix interrupt handler freeing
    41c0ba64de net/bonding: fix slave stop and remove on port close
    5a8afc69af net/bonding: fix stopping non-active slaves
    e856fe9aa6 doc: update matching versions in ice guide
    82ccc27de5 net/dpaa: fix event queue detach
    d24d6395d6 vdpa/mlx5: fix dead loop when process interrupted
    879fb64517 vdpa/mlx5: fix interrupt trash that leads to crash
    78414da84e vhost: fix missing virtqueue lock protection
    e3036fbd0a net/vhost: fix TSO feature default disablement
    4852da727c net/virtio: restore some optimisations with AVX512
    58d1b856be net/vhost: fix access to freed memory
    24dabb9d25 net/cxgbe: fix Tx queue stuck with mbuf chain coalescing
    6627ee48b5 net/cxgbe: fix port ID in Rx mbuf
    8cf194f699 net/bonding: fix RSS key config with extended key length
    3192737d10 net/nfp: remove unneeded header inclusion
    8ab93b06bc net/netvsc: fix hot adding multiple VF PCI devices
    03e1864411 test/mem: disable ASan when accessing unallocated memory
    e9b46ab763 net/mlx5: fix LRO configuration in drop Rx queue
    d5fdf0a2ba net/mlx5: fix LRO validation in Rx setup
    28ecf49a60 examples/l2fwd-crypto: fix stats refresh rate
    aeca5959dd common/dpaax: fix short MAC-I IV calculation for ZUC
    5a9af71a6d crypto/dpaa2_sec: fix operation status for simple FD
    5e3a3f48d1 crypto/dpaa2_sec: fix crypto operation pointer
    4644779034 crypto/dpaa_sec: fix secondary process probing
    15a3ae1a5f crypto/dpaa2_sec: fix chained FD length in raw datapath
    bee2c296c8 crypto/dpaa_sec: fix chained FD length in raw datapath
    86ba4e206e crypto/dpaa2_sec: fix buffer pool ID check
    f72e482fec crypto/dpaa2_sec: fix fle buffer leak
    8bad3a05f1 crypto/mlx5: fix login cleanup
    be6637f158 security: fix SA lifetime comments
    bb386a9f91 crypto/dpaa_sec: fix digest size
    f343d3b4ed eal: fix C++ include for device event and DMA
    de48c79f3b malloc: fix ASan handling for unmapped memory
    804b2e64eb mem: skip attaching external memory in secondary process
    65855b2d37 test/table: fix buffer overflow on lpm entry
    c7e0471948 net/mlx5: fix Rx/Tx stats concurrency
    b0e6a9c183 net/mlx5: fix GTP handling in header modify action
    b3896dba13 net/mlx5: restrict Rx queue array access to boundary
    c08c6247f2 net/mlx5: fix counter in non-termination meter
    99ba358268 net/mlx5: fix probing with secondary bonding member
    1430ccb1db net/mlx5: fix Tx when inlining is impossible
    72691359fa common/mlx5: fix memory region range calculation
    550f0d8288 net/netvsc: fix calculation of checksums based on mbuf flag
    21edf23c6d net/ice: fix raw flow input pattern parsing
    aedf24edbb net/ice: refactor parser usage
    bb6683a89f net/ice: add missing Tx burst mode name
    91355ad5b2 net/i40e: populate error in flow director parser
    8ae457cbf5 net/ice: improve performance of Rx timestamp offload
    a25197930d test/bpf: skip test if libpcap is unavailable
    6da5f268db examples/bond: fix invalid use of trylock
    9c267cbd10 net/dpaa2: fix dpdmux default interface
    d8898f0763 eal/windows: add missing C++ include guards
    fad1dbc0c5 eal/windows: fix data race when creating threads
    95e04d4866 doc: fix release note typo
    592c7bf714 net/af_xdp: make compatible with libbpf >= 0.7.0
    6721fb14eb net/af_xdp: use libxdp if available
    fcd039e466 version: 21.11.1
    2130012318 net/cnxk: fix build with optimization
    9518bcf700 net/mlx5: fix flex item availability
    05aa560efc version: 21.11.1-rc1
    b68dbab7c8 Revert "net/mlx5: fix flex item availability"
    bb5ce0625c crypto/ipsec_mb: fix GMAC parameters setting
    cef6bb00ce crypto/ipsec_mb: fix length and offset settings
    be2edca509 Revert "crypto/ipsec_mb: fix length and offset settings"
    dec4b1b89e raw/ifpga: fix build with optimization
    4586b6b8c2 doc: fix telemetry example in cryptodev guide
    2740b29e48 doc: fix missing note on UIO module in Linux guide
    713a4bc48c doc: replace characters for (R) symbol in Linux guide
    a50b228d2d net/mlx5: fix CPU socket ID for Rx queue creation
    8db2867c79 net/mlx5: fix port matching in sample flow rule
    7c12be128c eventdev: fix clang C++ include
    4f263532d0 cryptodev: fix clang C++ include
    ec8a6dc2e6 compressdev: fix missing space in log macro
    37232971b0 eal/freebsd: add missing C++ include guards
    8320df4804 examples/l3fwd: fix buffer overflow in Tx
    3313fe0301 app/testpmd: fix flow rule with flex input link
    39d09d7155 app/testpmd: fix GTP header parsing in checksum engine
    514668e230 app/testpmd: fix show RSS RETA on Windows
    3a3d4d3332 app/regex: fix number of matches
    f2a457c605 bpf: fix build with some libpcap version on FreeBSD
    e84b43b5eb crypto/ipsec_mb: fix GCM requested digest length
    8c7bebaa38 net/af_xdp: fix custom program loading with multiple queues
    88dbe7c555 net/qede: fix maximum Rx packet length
    09891782a4 net/qede: fix Rx bulk
    506f3198ab net/qede: fix Tx completion
    268985d32e doc: fix modify field action description for mlx5
    59a419a416 net/mlx5: fix implicit tag insertion with sample action
    42cf1850e2 net/mlx5: forbid multiple ASO actions in a single rule
    dd859e1797 net/mlx5: fix sample flow action on trusted device
    7680d1d321 net/mlx5: fix VLAN push action validation
    691ff0b6db net/mlx5: fix NIC egress flow mismatch in switchdev mode
    6cb68162e4 vhost: fix FD leak with inflight messages
    4c40d30d2b vhost: fix queue number check when setting inflight FD
    6ae8ba6b7a build: suppress rte_crypto_asym_op abi check
    efd091d541 devtools: fix symbols check
    026470bafa build: hide local symbols in shared libraries
    89f14be564 common/mlx5: consider local functions as internal
    6e7f8939f2 regexdev: fix section attribute of symbols
    6472c2d476 net/iavf: fix potential out-of-bounds access
    67191a9cb3 net/sfc: reduce log level of tunnel restore info error
    ee836190a1 net/mlx5: fix meter creation default state
    a17cea76b7 net/mlx5: fix configuration without Rx queue
    d31463e0b2 net/mlx5: fix MPLS/GRE Verbs spec ordering
    48fe9efaf2 net/mlx5: fix flex item availability
    3bd5cf393d net/mlx5: fix meter policy creation assert
    c77572d2a1 net/mlx5: remove unused reference counter
    0036f3941e net/mlx5: fix modify port action validation
    eebfb74c51 net/mlx5: fix shared RSS destroy
    5d3ade99bd net/mlx5: fix next protocol RSS expansion
    4500ec704f net/mlx5: fix inet IPIP protocol type
    9bdcba122b net/bnxt: fix null dereference in session cleanup
    4aadf56c66 ethdev: fix doxygen comments for device info struct
    0c7cbe52f7 build: fix build on FreeBSD with Meson 0.61.1
    dab4a96be2 devtools: remove event/dlb exception in ABI check
    4fa43b7bff vhost: fix physical address mapping
    f03f4b98c9 net/cnxk: fix Rx/Tx function update
    3a5e1aaee4 net/mlx5: fix initial link status detection
    295f5022f6 net/mlx5: fix link status change detection
    be828a8eaf common/mlx5: add Netlink event helpers
    7214354c52 examples/kni: add missing trailing newline in log
    f5ba75eb9a examples/l3fwd: make Rx and Tx queue size configurable
    ef48f23bfd examples/l3fwd: share queue size variables
    6bf720d7d7 examples/flow_classify: fix failure message
    2719708908 examples/distributor: reduce Tx queue number to 1
    7aa3bbafd6 app/dumpcap: check for failure to set promiscuous
    955a6afc6f test/bpf: skip dump if conversion fails
    e71f3dc931 pcapng: handle failure of link status query
    b8222349eb app/pdump: abort on multi-core capture limit
    8adbf6df92 raw/ifpga: fix monitor thread
    69da51b405 raw/ifpga: fix interrupt handle allocation
    d4536cf86a raw/ifpga: fix variable initialization in probing
    186250df3d gpu/cuda: fix dependency loading path
    af8ffbba79 sched: remove useless malloc in PIE data init
    8ebcaf23cb eal/linux: fix device monitor stop return
    89d84883b0 examples/vhost: fix launch with physical port
    7a5659dd94 vhost: fix linker script syntax
    b7f396be62 net/ice: fix Tx offload path choice
    28acfe550d common/cnxk: fix mbuf data offset for VF
    51af57d005 common/cnxk: fix bitmap usage for TM
    43dec151be net/iavf: fix AES-GMAC IV size
    f314e6acfb net/mlx5: fix flex item header length translation
    1926a8d8c5 net/mlx5: fix matcher priority with ICMP or ICMPv6
    1f5aede9bd net/mlx5: reduce flex item flow handle size
    279cc42d3b net/mlx5: fix GRE item translation in Verbs
    39cba36e63 doc: fix typos and punctuation in flow API guide
    41510092eb net/kni: fix config initialization
    6090ee620d net/txgbe: fix queue statistics mapping
    8a301f166c net/mlx5: fix check in count action validation
    c46eaf6f4c net/mlx5: fix shared counter flag in flow validation
    de3ad851ca net/mlx5: fix destroying empty matchers list
    6468addfe3 net/mlx5: fix indexed pool fetch overlap
    ae071e1851 net/iavf: fix function pointer in multi-process
    b82b6ed613 net/iavf: support NAT-T / UDP encapsulation
    5f275a0312 net/ixgbe: fix FSP check for X550EM devices
    aa6f865e7e net/hns3: increase time waiting for PF reset completion
    94420985c7 net/hns3: fix VF RSS TC mode entry
    dc3cb423f5 net/hns3: fix RSS TC mode entry
    772292049b net/hns3: remove duplicate macro definition
    24939fcc13 compressdev: fix socket ID type
    30fea0f0a6 app/compress-perf: fix number of queue pairs to setup
    b2b15ab556 app/compress-perf: fix socket ID type during init
    8ace98122a compress/mlx5: support out-of-space status
    d386e37612 app/compress-perf: optimize operations pool allocation
    c65e648405 app/compress-perf: fix cycle count operations allocation
    9bb7a3f9df event/dlb2: add shift value check in sparse dequeue
    d2b19d6346 event/cnxk: fix Rx adapter config check
    dd8c73295c event/cnxk: fix sub-event clearing mask length
    170c124998 kni: fix freeing order in device release
    0617d94900 bus/pci: assign driver pointer before mapping
    099aba7265 devargs: fix crash with uninitialized parsing
    dcf545fce1 eal/linux: fix illegal memory access in uevent handler
    38c59b06b0 distributor: fix potential overflow
    77b6873f73 efd: fix uninitialized structure
    b017e1159f test/efd: fix sockets mask size
    e9100a0196 doc: add CUDA driver features
    9703132099 app/testpmd: fix build without drivers
    158012beee app/testpmd: fix raw encap of GENEVE option
    8c4ce4d7ff net/i40e: fix unintentional integer overflow
    3334722c21 net/cnxk: fix RSS RETA table update
    b8bfbcd1a0 net/cnxk: fix build with GCC 12
    c957e1063b net/cnxk: fix inline IPsec security error handling
    ee97d867e7 net/cnxk: register callback early to handle initial packets
    c5124d0ea8 net/cnxk: fix inline device RQ tag mask
    283f54ba9d mempool/cnxk: fix batch allocation failure path
    ba9d00afac doc: correct name of BlueField-2 in mlx5 guide
    9385e97741 doc: replace broken links in mlx guides
    239796f3dd doc: remove obsolete vector Tx explanations from mlx5 guide
    2007577b29 net/mlx5: fix E-Switch manager vport ID
    a600672d1a net/mlx5: fix entry in shared Rx queues list
    7f982e1320 net/mlx5: fix meter sub-policy creation
    7b5ea7efc3 net/mlx5: remove unused function
    aff5b2ee60 net/mlx5: set flow error for hash list create
    d2e99680f9 common/mlx5: fix queue pair ack timeout configuration
    233c5aa3e7 net/ena: fix checksum flag for L4
    f5eff853e4 net/ena: check memory BAR before initializing LLQ
    70c3e891d0 net/ena: fix meta descriptor DF flag setup
    867dd857f4 net/ena: fix reset reason being overwritten
    c443512e3d net/ena: skip timer if reset is triggered
    4e9e9e29c4 net/ena: remove unused offload variables
    e63e5c79ce net/ena: remove unused enumeration
    399b489328 net/txgbe: fix debug logs
    a8be311dd1 net/ngbe: fix debug logs
    c1cf1a9735 app/testpmd: fix GENEVE parsing in checksum mode
    036993974f net/mlx5: fix errno update in shared context creation
    b6b1c3ad5d net/mlx5: fix ASO CT object release
    49257a9394 net/mlx5: fix ineffective metadata argument adjustment
    50f3a03f75 net/mlx5: fix sibling device config check
    e68285796c net/i40e: enable maximum frame size at port level
    15ff989ca8 net/iavf: fix segmentation offload buffer size
    dbb1c53725 net/iavf: fix segmentation offload condition
    d75be6c28d net/ice: fix overwriting of LSE bit by DCF
    a628e2bf19 net/af_xdp: ensure socket is deleted on Rx queue setup error
    ae2f030ad1 net/sfc: fix memory allocation size for cache
    ea21c6bf4e net/sfc: fix flow tunnel support detection
    a58ae9af98 common/sfc_efx/base: add missing handler for 1-byte fields
    4874f1d005 common/sfc_efx/base: fix recirculation ID set in outer rules
    e4b43ee28c net/cnxk: fix uninitialized local variable
    f0cfb0e3d1 common/cnxk: fix uninitialized pointer read
    2f61027cda common/cnxk fix unintended sign extension
    7eeb8d37ed common/cnxk: add missing checks of return values
    dd1851c1de net/af_xdp: add missing trailing newline in logs
    6a9b64907e common/cnxk: fix NPC key extraction validation
    87b639b4ed vhost: fix unsafe vring addresses modifications
    01e3dee29c vhost: fix field naming in guest page struct
    e09a0094a6 common/cnxk: fix base rule merge
    1751e87f51 common/cnxk: fix log level during MCAM allocation
    d91869302f common/cnxk: fix flow deletion
    450ee57e5f app/testpmd: check starting port is not in bonding
    387187932f net/bonding: fix slaves initializing on MTU setting
    c93302dd4f net/cnxk: fix mbuf data length
    116bfaa14e ethdev: fix MAC address in telemetry device info
    a42a874599 net/iavf: reset security context pointer on stop
    496747d389 net/txgbe: reset security context pointer on close
    223010f1da net/ixgbe: reset security context pointer on close
    967cb49748 net/nfb: fix multicast/promiscuous mode switching
    afe8e58fed net/nfb: fix array indexes in deinit functions
    daf06c45e8 crypto/ipsec_mb: fix length and offset settings
    cfa7703c8e crypto/ipsec_mb: fix ZUC operation overwrite
    1170e24b20 crypto/ipsec_mb: fix ZUC authentication verify
    bbc596578a crypto/ipsec_mb: check missing operation types
    9c67637c8c crypto/virtio: fix out-of-bounds access
    301ee2f378 baseband/acc100: avoid out-of-bounds access
    79247ddc0d examples/l2fwd-crypto: fix port mask overflow
    5772c7b32e doc: fix FIPS guide
    ad76dc4e91 examples/ipsec-secgw: fix buffer freeing in vector mode
    f092922c36 cryptodev: fix RSA key type name
    c8bcbe8b68 crypto/ipsec_mb: remove useless check
    fec66e64e5 event/cnxk: fix uninitialized local variables
    52d824d106 event/cnxk: fix variables casting
    9a552423fd event/dlb2: poll HW CQ inflights before mapping queue
    720fb431b4 event/dlb2: update rolling mask used for dequeue
    7d7a9f161d eventdev/eth_rx: fix queue config query
    529f3a735e eventdev/eth_rx: fix parameters parsing memory leak
    d33bb6bd28 examples/qos_sched: fix core mask overflow
    9970eab8c4 doc: improve configuration examples in idxd guide
    b254386fad dma/idxd: configure maximum batch size to high value
    ebc0188ccb test/dma: fix missing checks for device capacity
    c6aea57d99 dma/hisilicon: use common PCI device naming
    56d6e5b091 ethdev: fix cast for C++ compatibility
    5d75eb0924 cryptodev: add missing C++ guards
    c02f5bcfe9 bpf: add missing C++ guards
    362921a8e3 vhost: add missing C++ guards
    fb37e2b3ae kni: add missing C++ guards
    e4dbb6873a eventdev: add missing C++ guards
    3d1746c9ac compressdev: add missing C++ guards
    6fca954338 acl: add missing C++ guards
    447210e07c metrics: add missing C++ guards
    b99a45df05 ethdev: add missing C++ guards
    e7291176c2 telemetry: add missing C++ guards
    b2f85a808a eal: add missing C++ guards
    81c40b01d0 dmadev: add missing header include
    692ae335d6 eventdev/eth_tx: fix queue add error code
    adfebc59b5 pipeline: fix table state memory allocation
    1e8aa23aba pipeline: fix annotation checks
    13ddcf9dee raw/ntb: clear all valid doorbell bits on init
    0627e93c26 crypto/dpaax_sec: fix auth/cipher xform chain checks
    0fd24703c6 crypto/cnxk: fix update of number of descriptors
    2630bff5a4 compress/octeontx: fix null pointer dereference
    6f9d8df3d1 crypto/qat: fix GEN4 AEAD job in raw data path
    98ec92641b crypto/ipsec_mb: fix buffer overrun
    13aab9f493 crypto/ipsec_mb: fix premature dereference
    98ece68514 test/crypto: fix out-of-place SGL in raw datapath
    4d5d4d7abc examples/ipsec-secgw: fix offload flag used for TSO IPv6
    abfad6b59c net/txgbe: fix KR auto-negotiation
    42960ce408 net/txgbe: fix link up and down
    59691181a3 net/ngbe: fix packet statistics
    b9c20ea8f0 net/ngbe: fix Tx hang on queue disable
    3698c17f42 net/ngbe: fix missed link interrupt
    cacbd7e4f7 net/ngbe: fix Rx by initializing packet buffer early
    863d787942 net/bnxt: fix ring calculation for representors
    e53da2ffbe net/bnxt: set HW coalescing parameters
    6c8ff52958 net/mlx5: fix inline length for multi-segment TSO
    3831da6c7b net/mlx5: fix meter capabilities reporting
    6022babd1d net/mlx5: fix committed bucket size
    c9a140e15b net/mlx5: fix metadata endianness in modify field action
    8f821b1135 vdpa/sfc: fix null dereference during removal
    5dfd488d82 vdpa/sfc: fix null dereference during config
    7537c99618 net/ice: fix build with 16-byte Rx descriptor
    607d564355 net/ice: fix pattern check in flow director
    d422a9cdae net/ice/base: add profile validation on switch filter
    5dc74f1348 net/iavf: count continuous DD bits for Arm in flex Rx
    68522027e3 net/iavf: count continuous DD bits for Arm
    f746bb72ba net/iavf: fix null pointer dereference
    b832a197fa net/sfc: demand Tx fast free offload on EF10 simple datapath
    915b0b0b9f net/sfc: do not push fast free offload to default TxQ config
    6fdd1953b0 ethdev: remove unnecessary null check
    851b597291 net: fix L2TPv2 common header
    d594afc792 net/memif: remove pointer deference before null check
    273bacf2a8 config: align mempool elements to 128 bytes on CN10K
    e183e43e2b vfio: cleanup the multiprocess sync handle
    c32322e508 ipc: end multiprocess thread during cleanup
    6e1bc26cde test/mbuf: fix mbuf data content check
    472f790f95 app/fib: fix division by zero
    1058b2c369 mem: check allocation in dynamic hugepage init
    c59904ed03 vhost: fix C++ include
    6afaa0f3d7 table: fix C++ include
    91b9d6cd34 ipsec: fix C++ include
    4f328f8e2b graph: fix C++ include
    3668e54828 eventdev: fix C++ include
    1fdfd87f14 eal: fix C++ include
    72334ceaf1 config/arm: add values for native armv7
    02a96ad251 stack: fix stubs header export
    6b06137c98 regex/mlx5: fix memory allocation check
    72487940d1 net/virtio: fix slots number when indirect feature on
    160769f648 vhost: fix guest to host physical address mapping
    eaf935f63c net/sfc: fix lock releases
    ce413e1922 app/testpmd: fix stack overflow for EEPROM display
    ac180f4d26 net/tap: fix to populate FDs in secondary process
    721d0bbd16 ethdev: add internal function to device struct from name
    605d1de0d3 app/testpmd: fix bonding mode set
    7b71bc2d00 net/bonding: fix reference count on mbufs
    26f2cc6490 net/bonding: fix promiscuous and allmulticast state
    30dcde8467 net/ixgbe: check filter init failure
    e72696baa4 net/hns3: delete duplicated RSS type
    2ae91ac660 net/hns3: fix operating queue when TCAM table is invalid
    2b7587ea99 net/hns3: fix double decrement of secondary count
    10342b22ae net/hns3: fix insecure way to query MAC statistics
    9b1f69f906 net/hns3: fix RSS key with null
    d7033074e0 net/hns3: fix max packet size rollback in PF
    2c27da1e51 net/bonding: fix MTU set for slaves
    9ac1343c4d net/dpaa2: fix null pointer dereference
    90386f428c net/enic: fix dereference before null check
    57b2aa0265 test/mem: fix error check
    32cb4f09ff eal/windows: fix error code for not supported API
    5a9f8c2ba4 ring: fix overflow in memory size calculation
    8b45a1dea3 ring: fix error code when creating ring
    63cb4ae54f doc: fix KNI PMD name typo
    4f140c9a9a build: remove deprecated Meson functions
    aa8ad3e48c build: fix warnings when running external commands
    1e770ae599 pflock: fix header file installation
    86f7ed09ae doc: update matching versions in ice guide
    37d27abc59 net/mlx5: reject jump to root table
    bc3452d45d common/mlx5: fix probing failure code
    99f5cd0dc3 net/mlx5: fix mark enabling for Rx
    d157628041 common/mlx5: fix MR lookup for non-contiguous mempool
    4c4c0cf459 net/virtio: fix uninitialized RSS key
    0d2ddde419 net/virtio-user: check FD flags getting failure
    4210bb89d8 net/virtio-user: fix resource leak on probing failure
    efc7ea9dd7 vdpa/ifc: fix log info mismatch
    7c58dbf159 net/virtio: fix Tx queue 0 overriden by queue 128
    f05bbce185 vdpa/mlx5: workaround queue stop with traffic
    ad51b31a30 net/hns3: fix using enum as boolean
    9d6db3c3ad net/nfp: free HW ring memzone on queue release
    961922eb71 net/bonding: fix RSS with early configure
    6492c9875d net/hns3: fix vector Rx/Tx when PTP enabled
    9c10b251a1 net/hns3: fix mailbox wait time
    e073f410fb net/hns3: fix Rx/Tx functions update
    581e547a6f net/memif: remove unnecessary Rx interrupt stub
    5de680a494 raw/ifpga/base: fix port feature ID
    0f8f337740 net/bnxt: fix VF resource allocation strategy
    f70203b5c0 net/bnxt: fix memzone allocation per VNIC
    e44c18821c net/bnxt: handle ring cleanup in case of error
    a04034b131 net/bnxt: fix check for autoneg enablement
    72db0cca69 raw/ifpga: fix thread closing
    7c682d5c05 net/ice: fix link up when starting device
    b38f8855d6 net/ice: fix mbuf offload flag for Rx timestamp
    81597d6e20 raw/ifpga/base: fix SPI transaction
    4599a6179a net/sfc: validate queue span when parsing flow action RSS
    c935f2719d ethdev: fix Rx queue telemetry memory leak on failure
    3fd3c3b3b0 common/cnxk: fix error checking
    2253ed93c3 common/cnxk: fix uninitialized variables
    38f3a00894 common/cnxk: fix null pointer dereferences
    1349f9e568 common/cnxk: always use single interrupt ID with NIX
    cfcdf00068 common/cnxk: reset stale values on error debug registers
    285183e606 common/cnxk: fix byte order of frag sizes and infos
    5deff57b9d common/cnxk: fix shift offset for TL3 length disable
    41569f9deb net/nfp: remove useless range checks
    23c2f68598 net/nfp: remove duplicated check when setting MAC address
    85d9e45c32 net/mlx5: fix MPRQ WQE size assertion
    a9bc2a46c2 net/mlx5: fix maximum packet headers size for TSO
    70211750cc net/bnxt: restore dependency on kernel modules
    279f0d75c0 net/dpaa2: fix timestamping for IEEE1588
    c96ea2bf1c net/dpaa2: fix unregistering interrupt handler
    699c30f853 net/cxgbe: fix dangling pointer by mailbox access rework
    ef94549efe app/testpmd: fix external buffer allocation
    6d5f3984dc app/testpmd: fix dereference before null check
    83774f8a67 net/bonding: fix mode type mismatch
    40a4d0544b net/af_xdp: fix build with -Wunused-function
    181ddedb1a net/axgbe: use PCI root complex device to distinguish device
    bb1854bc69 app/testpmd: fix Tx scheduling interval
    96b92d045f net/bonding: fix offloading configuration
    661587eaae net/cnxk: fix promiscuous mode in multicast enable flow
    26a3e3e7d3 net/bnxt: check VF representor pointer before access
    2f9df1413c net/bnxt: fix xstats query
    b74a60df81 net/bnxt: fix crash by validating pointer
    2e31b779e8 net/bnxt: fix PAM4 mask setting
    6c57090c01 net/bnxt: fix ring teardown
    f2c08d53a1 net/bnxt: fix handling of VF configuration change
    377a9a8197 net/bnxt: get maximum supported multicast filters count
    b0fe5e2fa9 net/bnxt: fix flow create when RSS is disabled
    6b722d7b37 net/bnxt: add null check for mark table
    a31a8b6a97 net/bnxt: set fast-path pointers only if recovery succeeds
    6b7c0ce0ce net/bnxt: cap maximum number of unicast MAC addresses
    a9ea24c80c net/bnxt: fix restoring VLAN filtering after recovery
    56f92b77e7 net/bnxt: restore RSS configuration after reset recovery
    880ed79159 net/bnxt: fix queue stop operation
    f4d1e64dec net/bnxt: fix multicast MAC restore during reset recovery
    5e35fae222 net/bnxt: fix multicast address set
    c59f883c24 net/bnxt: fix xstats names query overrun
    9d1da3652a net/mlx5: relax headroom assertion
    ab06c7bf9b net/mlx5: fix GCC uninitialized variable warning
    379079d6cc net/mlx5: fix GRE protocol type translation for Verbs
    d8d54171bd net/mlx5: fix RSS expansion with explicit next protocol
    032e27c0b2 net/mlx5: fix assertion on flags set in packet mbuf
    59f8d27b5f common/mlx5: fix missing validation in devargs parsing
    407b3ae746 net/mlx5: fix memory socket selection in ASO management
    751bca90b1 common/mlx5: fix error handling in multi-class probe
    0832935bf5 net/ixgbe: add vector Rx parameter check
    1eef1cf7d3 net/ice: fix Tx checksum offload
    76a729e7ed net/ice: track DCF state of PF
    85e84c5930 net/iavf: remove git residue symbol
    3380c428a5 net/ice: fix Tx checksum offload capability
    a9ff22fc59 net/ice: fix pattern check for flow director parser
    f1339fd8ec net/qede: fix redundant condition in debug code
    9ff875ecff common/cnxk: fix nibble parsing order when dumping MCAM
    23b8e0a337 net/mlx5: fix MPRQ stride devargs adjustment
    c58aaabede net/mlx5: improve stride parameter names
    f873364dfe common/mlx5: add minimum WQE size for striding RQ
    0422d79548 net/mlx5: fix modify field MAC address offset
    d021a2f9b7 dma/cnxk: fix installing internal headers
    bb6b3ec4e9 devtools: fix comment detection in forbidden token check
    19aefaf2cb examples/ipsec-secgw: fix default flow rule creation
    8c4f0e9e73 examples/ipsec-secgw: fix eventdev start sequence
    5831db3bab crypto/ipsec_mb: fix tainted data for session
    4b8475c98e crypto/ipsec_mb: fix queue cleanup null pointer dereference
    07ee507051 crypto/ipsec_mb: fix queue setup null pointer dereference
    7823f35581 crypto/cnxk: fix extend tail calculation
    5977020bc3 crypto/cnxk: fix inflight count calculation
    99d6741b64 crypto/cnxk: enable allocated queues only
    de6b483f38 common/cnxk: fix reset of fields
    7ee503d33f common/cnxk: add workaround for vWQE flush
    e3b9a8c32f event/cnxk: fix QoS devargs parsing
    87646d04a1 examples/l3fwd: fix Rx burst size for event mode
    8d0ffec0cf eventdev/eth_rx: fix missing internal port checks
    393d0580db doc: fix dlb2 guide
    19c6e95cd6 eal/linux: log hugepage create errors with filename
    24e496918b config: add arch define for Arm
    a8dd54379d gpu/cuda: fix memory list cleanup
    8e8fe373c0 dma/idxd: fix wrap-around in burst capacity calculation
    e0f7faeba1 dma/idxd: fix paths to driver sysfs directory
    cb7d9a39cb dma/idxd: fix burst capacity calculation
    572305874a bus/ifpga: remove useless check while browsing devices
    c30f1ec97d doc: remove dependency on findutils on FreeBSD
    cb2e09a4da buildtools: fix AVX512 check for Python 3.5
    3b511fdf21 maintainers: update for stable branches
    b3122779a5 doc: replace deprecated distutils version parsing
    2be1e5158e fix spelling in comments and strings


* Wed Aug 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-48
- Merging upstream branch-2.17 [RH git: ed428149e4]
    Commit list:
    dfc3e65c81 raft: Fix unnecessary periodic compactions.
    6f322ccf8a netdev-offload-tc: Parse tunnel options only for geneve ports.


* Mon Aug 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-47
- Merging upstream branch-2.17 [RH git: 080c941dff]
    Commit list:
    a9f10a2bdc netdev-offload-tc: Add missing handling of the tunnel source port.
    ec2e967c1d netdev-offload-tc: Fix ignoring unknown tunnel keys.
    686984d9a0 netdev-offload-tc: Use masks instead of keys while parsing tunnel attributes.
    92c072d944 netdev-offload-tc: Explicitly handle mask for the tunnel destination port.
    87f191a3a3 netdev-offload-tc: Fix the mask for tunnel metadata length.


* Tue Aug 16 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-46
- Merging upstream branch-2.17 [RH git: 020b9deea5]
    Commit list:
    cadcea6fea releases: Mark 2.17 as a new LTS release.


* Mon Aug 15 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-45
- Merging upstream branch-2.17 [RH git: 824e124b3b]
    Commit list:
    8a1b734480 handlers: Fix handlers mapping.
    713072fdac handlers: Create additional handler threads when using CPU isolation.


* Fri Aug 12 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-44
- Merging upstream branch-2.17 [RH git: 7e55c5405a]
    Commit list:
    84a8910ffe packets: Fix misaligned access to ip6_hdr.
    fe27e0c884 python: Do not send non-zero flag for a SSL socket. (#2115035)
    729a872f19 dpif-netdev: Simplify AVX512 build time checks to enhance readability.


* Wed Aug 10 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-43
- pkgtool: keep %{?dist} before added bz string [RH git: 0c88379419]
    Signed-off-by: Timothy Redaelli <tredaelli@redhat.com>


* Tue Aug 09 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-42
- Merging upstream branch-2.17 [RH git: 690a14282a]
    Commit list:
    1b566f8b80 github: Move CI to ubuntu 20.04 base image.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-41
- Merging upstream branch-2.17 [RH git: d208bfac1d]
    Commit list:
    86725abe10 netdev-offload-tc: Disable offload of IPv6 fragments.
    2276daf889 ovs-save: Use right OpenFlow version for add-tlv-map.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-40
- Merging upstream branch-2.17 [RH git: e21f40b07e]
    Commit list:
    c353e757d7 system-traffic: Fix IPv4 fragmentation test sequence for check-kernel.
    6f54dc134a system-traffic: Fix incorrect neigh entry in ipv6 header modification test.
    7848ae6ffb system-traffic: Don't run IPv6 header modification test on kernels < 5.19.


* Fri Aug 05 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-39
- Merging upstream branch-2.17 [RH git: 7a3929ad1f]
    Commit list:
    399185865e netdev-linux: set correct action for packets that passed policer


* Thu Aug 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-38
- Merging upstream branch-2.17 [RH git: 862609bde4]
    Commit list:
    cda60c8558 python: Fix E275 missing whitespace after keyword.
    3678fb544d tc: Use sparse hex dump while printing inconsistencies.
    03a0ec82b7 netdev-offload-tc: Print unused mask bits on failure.
    5b8453a44e dynamic-string: Add function for a sparse hex dump.
    8d7cb1daf4 dpif-netlink: Fix incorrect bit shift in compat mode.
    d1cec26869 python: Use setuptools instead of distutils.
    8d6ecb2592 packets: Re-calculate IPv6 checksum only for first frag upon modify.


* Fri Jul 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-37
- Merging upstream branch-2.17 [RH git: 083e7533dc]
    Commit list:
    26dbc822d3 test-ovsdb: Fix false-positive leaks from LeakSanitizer.
    6eab10cf2c m4: Update ax_func_posix_memalign to the latest version.
    2f51bfd23b m4: Replace obsolete AC_HELP_STRING with AS_HELP_STRING.
    8ad325aab5 libopenvswitch.pc: Add missing libs for a static build.
    b64ff3f480 rhel: Stop installing internal headers.
    b63bbf2dba python-c-ext: Handle initialization failures.
    4ad02ad047 netdev-linux: Do not touch LAG members if master is not attached to OVS.
    e6dcd07bc2 netdev: Clear auto_classified if netdev reopened with the type specified.


* Mon Jul 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-36
- Merging upstream branch-2.17 [RH git: 73fb18f95f]
    Commit list:
    1eedf45e81 system-traffic: Properly stop dangling ping after geneve test.
    fb8e34bdba conntrack: Fix conntrack multiple new state.
    af37f41188 python-c-ext: Fix a couple of build warnings.
    b7d9f76100 python-c-ext: Remove Python 2 support.


* Tue Jul 19 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-35
- Merging upstream branch-2.17 [RH git: 664435a0c0]
    Commit list:
    02fb4bfb87 netdev-offload-dpdk: Setting RSS hash types in RSS action.
    8e8fcf7bda lib: Print nw_frag in flow key.
    29d8ce1adc ovsdb: Remove extra make target dependency for local-config.5.


* Thu Jul 14 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-34
- Merging upstream branch-2.17 [RH git: 43bbc204f0]
    Commit list:
    13ac0bc7c6 tc: Fix misaligned access while creating pedit actions.


* Tue Jul 12 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-33
- Merging upstream branch-2.17 [RH git: 8edacddc16]
    Commit list:
    2c85d737a4 utilities/bashcomp: Fix incorrect file mode.


* Fri Jul 08 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-32
- Fix REPO_URL [RH git: 3c45153e77]


* Fri Jul 01 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-31
- Merging upstream branch-2.17 [RH git: f530505b5e]
    Commit list:
    05e9d2b7a9 Pmd.at: fix dpcls and dpif configuration test cases.


* Thu Jun 30 2022 Ilya Maximets <i.maximets@redhat.com> - 2.17.0-30
- Merging upstream branch-2.17 [RH git: a51734d307]
    Commit list:
    45ecaa9e57 ovsdb: Add Local_Config schema.
    
    Merge:
     redhat/template.spec.in updated with new files.
    
    Signed-off-by: Ilya Maximets <i.maximets@redhat.com>


* Wed Jun 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-29
- Merging upstream branch-2.17 [RH git: d8e3f49a8c]
    Commit list:
    61d64d3899 dpif-netdev: Fix leak of AVX512 DPIF scratch pad.


* Wed Jun 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-28
- Merging upstream branch-2.17 [RH git: f3aee3f437]
    Commit list:
    a77ad9693c dpif-netdev: Refactor AVX512 runtime checks. (#2100393)


* Tue Jun 28 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-27
- Merging upstream branch-2.17 [RH git: 7a72e1ae7e]
    Commit list:
    ccea7df578 dpif-netdev-extract-avx512: Protect GCC builtin usage.
    807f7f994a ovs-tcpdump: Default to OVS_RUNDIR if present.
    ec13b03ca3 ovsdb: Fix memory leak on error path in ovsdb_file_read__().
    8b2dff2e34 odp-util: Ignore unknown attributes in parse_key_and_mask_to_match(). (#2089331)
    13d97f6637 ofproto-dpif: Avoid unneccesary backer revalidation.
    9b4035d699 lldp: Fix lldp memory leak.
    d9351febc2 ipfix: Trigger revalidation if ipfix options changes.


* Mon Jun 27 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-26
- Merging upstream branch-2.17 [RH git: d488a56080]
    Commit list:
    5419b1de93 conntrack: Fix incorrect bit shift while hashing nat range.
    1ab5f94a11 packets: Fix misaligned write to MPLS lse.
    8e00be03c7 tc: Fix misaligned access to stats and time values.
    3a1f5341ca odp-util: Fix unaligned access to tunnel id.
    0c54c43b89 ofpbuf: Fix offsetting a NULL pointer in ofpbuf_reserve.


* Fri Jun 24 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-25
- Merging upstream branch-2.17 [RH git: a7a9ad68bb]
    Commit list:
    98edacb40c drop-stats.at: Fix frequent failures of the recursion too deep test.
    cbc13ce4f7 odp_util: Fix parse_key_and_mask_to_match() vlan parsing.


* Tue Jun 21 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-24
- Merging upstream branch-2.17 [RH git: 8f74cee909]
    Commit list:
    73e6ce4925 Prepare for 2.17.3.
    95979b0f0d Set release date for 2.17.2.


* Tue Jun 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-23
- Merging upstream branch-2.17 [RH git: 58de71ec1f]
    Commit list:
    250e1a6dd2 ofproto-dpif-xlate: Fix internal CT state for non-recirc traffic.
    fe870ee072 classifier: Adjust segment boundary to execute prerequisite processing. (#2081773)
    ec0ec464ba ovs-tcpdump: Fix error when stopping ovs-tcpdump.


* Tue May 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-22
- Merging upstream branch-2.17 [RH git: 2761ccda9c]
    Commit list:
    420823e2af ofproto-dpif: Fix meter use-after-free.
    c762da2623 ovs-rcu: Add ovsrcu_barrier.
    cd9b6b64f4 dpif-netdev: Fix ALB 'rebalance_intvl' max hard limit.
    64f6c49d25 dpif-netdev: Fix ALB parameters type mismatch.
    b11b84ea7f dpdk: Use DPDK 21.11.1 release.
    d3bf48e9a9 raft: Don't use HMAP_FOR_EACH_SAFE when logging commands.


* Thu May 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-21
- Merging upstream branch-2.17 [RH git: 97205fb19a]
    Commit list:
    e07377bb49 ovsdb: raft: Fix transaction double commit due to lost leadership. (#2046340)
    5da86cb360 dynamic-string: Fix undefined behavior due to offsetting null pointer.
    369e688908 Revert "odp-util: Always report ODP_FIT_TOO_LITTLE for IGMP."
    18341166ed ofproto-dpif-xlate: Fix netdev native tunnel neigh discovery spa.
    748e4b2b5b ovs-router: Expose the ovs_router_get_netdev_source_address function.
    34390bb35c ofproto-dpif: Trigger revalidation if ct tp changes.


* Wed May 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-20
- Merging upstream branch-2.17 [RH git: c0dd67b058]
    Commit list:
    1adb07e206 Carefully release NBL in Windows


* Wed May 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-19
- Merging upstream branch-2.17 [RH git: 5696d42501]
    Commit list:
    1ccaba4484 tests: Properly kill ovsdb test processes.
    260b091c2a ovs-save: Get highest ofp version error.
    7606bb1210 netdev-linux: Properly access 32-bit aligned rtnl_link_stats64 structs.
    0688b9f27d treewide: Avoid offsetting NULL pointers.
    92bcf0a823 treewide: Fix invalid bit shift operations.


* Thu May 05 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-18
- vhost: fix queue number check when setting inflight FD [RH git: ac46ea1a7e]
    [ upstream commit 6442c329b9d2ded0f44b27d2016aaba8ba5844c5 ]
    
    In function vhost_user_set_inflight_fd, queue number in inflight
    message is used to access virtqueue. However, queue number could
    be larger than VHOST_MAX_VRING and cause write OOB as this number
    will be used to write inflight info in virtqueue structure. This
    patch checks the queue number to avoid the issue and also make
    sure virtqueues are allocated before setting inflight information.
    
    Fixes: ad0a4ae491fe ("vhost: checkout resubmit inflight information")
    
    Reported-by: Wenxiang Qian <leonwxqian@gmail.com>
    Signed-off-by: Chenbo Xia <chenbo.xia@intel.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Thu May 05 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-17
- vhost: fix FD leak with inflight messages [RH git: c2ac4edf6d]
    [ upstream commit af74f7db384ed149fe42b21dbd7975f8a54ef227 ]
    
    Even if unlikely, a buggy vhost-user master might attach fds to inflight
    messages. Add checks like for other types of vhost-user messages.
    
    Fixes: d87f1a1cb7b6 ("vhost: support inflight info sharing")
    
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Wed May 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-16
- Merging upstream branch-2.17 [RH git: acda732382]
    Commit list:
    7fa76371de utilities: Handle dumping packets in GDB TUI.
    8cac8baa8f ofproto-dpif-xlate: Remove mirror assert.
    e0e8f0c546 netdev-dpdk: Fix tx drops statistic for a down netdev.
    f9b5f8a781 netdev-dpdk: Remove a leftover lock annotation.
    4c3976ff2a netdev-dpdk: Refactor the DPDK transmit path.


* Wed May 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-15
- Merging upstream branch-2.17 [RH git: 9273c90557]
    Commit list:
    410b97c839 netdev-offload-dpdk: Fix ethernet type for VLANs.
    7948312feb netdev-offload-dpdk: Use has_vlan match attribute.


* Mon May 02 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-14
- Merging upstream branch-2.17 [RH git: 1a8dfc5537]
    Commit list:
    522c46884d python: idl: Raise AttributeError from uuid_to_row.


* Wed Apr 27 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-13
- Merging upstream branch-2.17 [RH git: b306be03b9]
    Commit list:
    cb24c524e4 ofproto-dpif-xlate: Clear out vlan flow fields while processing native tunnel. (#393566
    2060552)
    a665b75dec dpif-netdev-avx512: Fix overflow of UINT32_C(1).


* Tue Apr 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-12
- Merging upstream branch-2.17 [RH git: 1af56b0e7d]
    Commit list:
    60e7badd6e dpif-netdev-avx512: Fix ubsan shift error in bitmasks.
    9cc329ec5b python: Politely handle misuse of table.condition.
    0631be2b5a ofproto-xlate: Fix crash when forwarding packet between legacy_l3 tunnels.
    df97903099 system-traffic: Fix fragment reassembly with L3 L4 protocol information.


* Thu Apr 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-11
- Set RTE_ETH_MAXPORTS to 1024 [RH git: 5226ee22e0] (#2077451)
    Resolves: #2077451


* Mon Apr 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-10
- Merging upstream branch-2.17 [RH git: bf2a38bb7b]
    Commit list:
    ba159ee0f9 cirrus: Update FreeBSD versions.


* Thu Apr 14 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-9
- redhat: network-scripts are gone in RHEL9 [RH git: a15ee438ad]


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-8
- Merging upstream branch-2.17 [RH git: 3bd5aec051]
    Commit list:
    bd1a3b6b49 Prepare for 2.17.2.
    41bb202fb3 Set release date for 2.17.1.


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-7
- Merging upstream branch-2.17 [RH git: 052159c286]
    Commit list:
    8f42d4f597 NEWS: Highlight libopenvswitch API change caused by UB fixes.


* Wed Apr 06 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-6
- Merging upstream branch-2.17 [RH git: 928136477c]
    Commit list:
    14301b3a3c netdev-offload-tc: Check for ct_state flag combinations that are not offloadable.
    3a2eef7927 python: idl: Set cond_changed to true if condition change requested.
    d05ccf288d dpif-netdev: Fix dp_netdev_get_pmd() function getting correct core_id.
    79e291f983 alb.at: Add tests for cross-numa polling.
    9c3b74fb24 dpif-netdev: Fix PMD auto load balance with pmd-rxq-isolate.
    8580ff9ddd pmd.at: Add tests for multi non-local numa pmds.
    6bf4eeddbb dpif-netdev: Fix non-local numa selection for more than two numas.
    c41434b3b7 dpif-netdev: Fix typo in function name.
    e0aa5e1329 python: idl: Set cond_changed to false if last id is zero.
    8da40d31c7 ofproto-dpif-xlate: Fix NULL pointer dereference in xlate_normal().
    63a903ab42 ofproto/ofproto-dpif: Fix dpif_type for userspace tunnels.


* Mon Apr 04 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-5
- downstream: Enable usdt probes in build [RH git: d7746afd9c]
    Fixes: BZ1840877


* Wed Mar 30 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-4
- Merging upstream branch-2.17 [RH git: f6beee6395]
    Commit list:
    14d54eb8b6 sset: add SHORT version of SAFE loop macros.
    f0e63b115f sparse: bump recommended version and include headers.
    70b87cf722 idlc: support short version of SAFE macros.
    3777ed90c9 rculist: use multi-variable helpers for loop macros.
    bb52e9bebf hindex: remove the next variable in safe loops.
    7d6cbfa24b hindex: use multi-variable iterators.
    97ad96b63a cmap: use multi-variable iterators.
    cd62fda22d hmap: use short version of safe loops if possible.
    d56bfd7521 hmap: implement UB-safe hmap pop iterator.
    e2c8354861 hmap: use multi-variable helpers for hmap loops.
    897d6647e6 list: use short version of safe loops if possible.
    979a9eb5b5 list: use multi-variable helpers for list loops.
    6bacf802c6 util: add helpers to overload SAFE macro.
    f127123d66 util: add safe multi-variable iterators.
    38e73f0b68 util: add multi-variable loop iterator macros.


* Wed Mar 30 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.17.0-3
- Merging upstream branch-2.17 [RH git: 19d425fcfb]
    Commit list:
    e91edf4568 ovsdb: raft: Fix inability to read the database with DNS host names. (#2055097)
    2404d45367 system-traffic.at: Fix flaky DNAT load balancing test.
    6b8adfdd8d dpif-netdev: Keep orig_in_port as a field of the flow.
    6098b7f250 tests: Fix incorrect usage of OVS_WAIT_UNTIL.
    cf9018d373 odp-util: Fix output for tc to be equal to kernel.
    992de24063 netdev-offload-tc: Fix IP and port ranges in flower returns.
    7e26796c03 netdev-offload-tc: Fix use of ICMP values instead of masks defines.
    e319e27064 netdev-offload-tc: Always include conntrack information to tc.
    51ef81ad78 netdev-offload-tc: Check for valid netdev ifindex in flow_put.
    974253dc2e netdev-offload-tc: Set the correct VLAN_VID and VLAN_PCP masks.
    c43c159aea netdev-offload-tc: Add debug logs on tc rule verify failures.
    d34622a03b tc: Keep header rewrite actions order.
    5255713d1f faq: Update OVS/DPDK version table for OVS 2.15/2.16
    05cf36a620 system-dpdk: Fix mfex autovalidator tests.
    87540e3b9f ofp-prop: Silence the 'may be uninitialized' warning.
    812164adef tests: Ignore log about failing to set NETLINK_EXT_ACK.
    ae51ccc12c ovsdb-cluster.at: Avoid test failures due to different hashing.
    f33cde23c7 ofproto: Use xlate map for uuid lookups.
    6ac255496c ofproto: Add refcount to ofproto to fix ofproto use-after-free.
    db0cc8be38 ofproto-dpif: Trigger revalidation when ipfix config set.
    31b86e5c98 conntrack: Prefer dst port range during unique tuple search.
    b761b532c3 conntrack: Select correct sport range for well-known origin sport.
    78bd058c36 ipsec: StrongSwan report connection update failures to ovs logs.
    aa05596dfb ipsec: Libreswan report connection failures to ovs logs.
    427776ceae system-tso: Skip encap tests when userspace TSO is enabled.
    66d16e2883 tc: Fix stats byte count on fragmented packets.
    b63c41f31f compat: Add gen_stats include to define tc hw stats.
    c531b3828f ovsdb: raft: Fix inability to join the cluster after interrupted attempt. (#2033514)
    498cedc483 reconnect: Fix broken inactivity probe if there is no other reason to wake up.
    5dc1423d80 datapath-windows: Fix NXM_OF_IP_TOS issue
    91c0f0068d Prepare for 2.17.1.


* Wed Mar 30 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-2
- redhat: fix setup on RHEL8 [RH git: 03255d5ae3]


* Mon Feb 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.17.0-1
- redhat: Imported Red Hat build files. [RH git: 4b0e1204d4]


